@@ -29,6 +29,7 @@ public:
         : Transaction(nullptr, nullptr, Transaction::InstallRole)
         , m_allUpdaters(updaters)
     {
+        setVisible(false);
         bool cancelable = false;
         for (auto updater : std::as_const(m_allUpdaters)) {
             connect(updater, &AbstractBackendUpdater::progressingChanged, this, &UpdateTransaction::slotProgressingChanged);
@@ -153,7 +154,7 @@ void ResourcesUpdatesModel::init()
     refreshFetching();
 
     // To enable from command line use:
-    // kwriteconfig5 --file discoverrc --group Software --key UseOfflineUpdates true
+    // kwriteconfig6 --file discoverrc --group Software --key UseOfflineUpdates true
     auto sharedConfig = KSharedConfig::openConfig();
     KConfigGroup group(sharedConfig, u"Software"_s);
     m_offlineUpdates = group.readEntry<bool>("UseOfflineUpdates", false);
@@ -165,9 +166,11 @@ void ResourcesUpdatesModel::init()
             return;
         }
 
-        if (m_offlineUpdates == group.readEntry<bool>("UseOfflineUpdates", false)) {
+        const bool offlineUpdates = group.readEntry<bool>("UseOfflineUpdates", false);
+        if (m_offlineUpdates == offlineUpdates) {
             return;
         }
+        m_offlineUpdates = offlineUpdates;
         Q_EMIT useUnattendedUpdatesChanged();
     });
 
@@ -372,11 +375,6 @@ bool ResourcesUpdatesModel::useUnattendedUpdates() const
     return m_offlineUpdates;
 }
 
-void ResourcesUpdatesModel::setOfflineUpdates(bool offline)
-{
-    m_offlineUpdates = offline;
-}
-
 QStringList ResourcesUpdatesModel::errorMessages() const
 {
     QStringList ret;
